@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of a MIDI file
 
-our $VERSION = '0.1101';
+our $VERSION = '0.1103';
 
 use Moo;
 use strictures 2;
@@ -432,7 +432,7 @@ MIDI::Ngram - Find the top repeated note phrases of a MIDI file
 
 =head1 VERSION
 
-version 0.1101
+version 0.1103
 
 =head1 SYNOPSIS
 
@@ -517,13 +517,15 @@ Default: C<undef>
 =head2 loop
 
 The number of times to choose a weighted phrase.  * This only works
-with the B<weight> option.
+in conjunction with the B<weight> option.
 
 Default: C<10>
 
 =head2 weight
 
-Boolean.  Play phrases by their ngram repetition occurrence.
+Boolean.  Play phrases according to the probability of their
+repetition occurrence with the
+L<List::Util::WeightedChoice/choose_weighted> function.
 
 Default: C<0>
 
